# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 3.9.0-develop.3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CreateTaskDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'type': 'str',
        'inputs': 'TaskInputs',
        'outputs': 'TaskOutputs'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'type': 'type',
        'inputs': 'inputs',
        'outputs': 'outputs'
    }

    def __init__(self, name=None, description=None, type=None, inputs=None, outputs=None):  # noqa: E501
        """CreateTaskDto - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._description = None
        self._type = None
        self._inputs = None
        self._outputs = None
        self.discriminator = None
        self.name = name
        if description is not None:
            self.description = description
        self.type = type
        if inputs is not None:
            self.inputs = inputs
        if outputs is not None:
            self.outputs = outputs

    @property
    def name(self):
        """Gets the name of this CreateTaskDto.  # noqa: E501


        :return: The name of this CreateTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateTaskDto.


        :param name: The name of this CreateTaskDto.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this CreateTaskDto.  # noqa: E501


        :return: The description of this CreateTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateTaskDto.


        :param description: The description of this CreateTaskDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def type(self):
        """Gets the type of this CreateTaskDto.  # noqa: E501


        :return: The type of this CreateTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateTaskDto.


        :param type: The type of this CreateTaskDto.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["DatabricksJob", "DataQuery", "ContainerExecution"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def inputs(self):
        """Gets the inputs of this CreateTaskDto.  # noqa: E501


        :return: The inputs of this CreateTaskDto.  # noqa: E501
        :rtype: TaskInputs
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        """Sets the inputs of this CreateTaskDto.


        :param inputs: The inputs of this CreateTaskDto.  # noqa: E501
        :type: TaskInputs
        """

        self._inputs = inputs

    @property
    def outputs(self):
        """Gets the outputs of this CreateTaskDto.  # noqa: E501


        :return: The outputs of this CreateTaskDto.  # noqa: E501
        :rtype: TaskOutputs
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """Sets the outputs of this CreateTaskDto.


        :param outputs: The outputs of this CreateTaskDto.  # noqa: E501
        :type: TaskOutputs
        """

        self._outputs = outputs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateTaskDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateTaskDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 3.9.0-develop.3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UpdateFeatureDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_name': 'str',
        'column_alias': 'str',
        'display_name': 'str',
        'feature_sub_category_id': 'str',
        'aggregation_type': 'str',
        'is_filter': 'bool',
        'is_trainable': 'bool',
        'is_explainable': 'bool',
        'is_categorical': 'bool',
        'category_values': 'object',
        'type': 'str'
    }

    attribute_map = {
        'column_name': 'columnName',
        'column_alias': 'columnAlias',
        'display_name': 'displayName',
        'feature_sub_category_id': 'featureSubCategoryId',
        'aggregation_type': 'aggregationType',
        'is_filter': 'isFilter',
        'is_trainable': 'isTrainable',
        'is_explainable': 'isExplainable',
        'is_categorical': 'isCategorical',
        'category_values': 'categoryValues',
        'type': 'type'
    }

    def __init__(self, column_name=None, column_alias=None, display_name=None, feature_sub_category_id=None, aggregation_type=None, is_filter=None, is_trainable=None, is_explainable=None, is_categorical=None, category_values=None, type=None):  # noqa: E501
        """UpdateFeatureDto - a model defined in Swagger"""  # noqa: E501
        self._column_name = None
        self._column_alias = None
        self._display_name = None
        self._feature_sub_category_id = None
        self._aggregation_type = None
        self._is_filter = None
        self._is_trainable = None
        self._is_explainable = None
        self._is_categorical = None
        self._category_values = None
        self._type = None
        self.discriminator = None
        if column_name is not None:
            self.column_name = column_name
        if column_alias is not None:
            self.column_alias = column_alias
        if display_name is not None:
            self.display_name = display_name
        if feature_sub_category_id is not None:
            self.feature_sub_category_id = feature_sub_category_id
        if aggregation_type is not None:
            self.aggregation_type = aggregation_type
        if is_filter is not None:
            self.is_filter = is_filter
        if is_trainable is not None:
            self.is_trainable = is_trainable
        if is_explainable is not None:
            self.is_explainable = is_explainable
        if is_categorical is not None:
            self.is_categorical = is_categorical
        if category_values is not None:
            self.category_values = category_values
        if type is not None:
            self.type = type

    @property
    def column_name(self):
        """Gets the column_name of this UpdateFeatureDto.  # noqa: E501


        :return: The column_name of this UpdateFeatureDto.  # noqa: E501
        :rtype: str
        """
        return self._column_name

    @column_name.setter
    def column_name(self, column_name):
        """Sets the column_name of this UpdateFeatureDto.


        :param column_name: The column_name of this UpdateFeatureDto.  # noqa: E501
        :type: str
        """

        self._column_name = column_name

    @property
    def column_alias(self):
        """Gets the column_alias of this UpdateFeatureDto.  # noqa: E501


        :return: The column_alias of this UpdateFeatureDto.  # noqa: E501
        :rtype: str
        """
        return self._column_alias

    @column_alias.setter
    def column_alias(self, column_alias):
        """Sets the column_alias of this UpdateFeatureDto.


        :param column_alias: The column_alias of this UpdateFeatureDto.  # noqa: E501
        :type: str
        """

        self._column_alias = column_alias

    @property
    def display_name(self):
        """Gets the display_name of this UpdateFeatureDto.  # noqa: E501


        :return: The display_name of this UpdateFeatureDto.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this UpdateFeatureDto.


        :param display_name: The display_name of this UpdateFeatureDto.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def feature_sub_category_id(self):
        """Gets the feature_sub_category_id of this UpdateFeatureDto.  # noqa: E501


        :return: The feature_sub_category_id of this UpdateFeatureDto.  # noqa: E501
        :rtype: str
        """
        return self._feature_sub_category_id

    @feature_sub_category_id.setter
    def feature_sub_category_id(self, feature_sub_category_id):
        """Sets the feature_sub_category_id of this UpdateFeatureDto.


        :param feature_sub_category_id: The feature_sub_category_id of this UpdateFeatureDto.  # noqa: E501
        :type: str
        """

        self._feature_sub_category_id = feature_sub_category_id

    @property
    def aggregation_type(self):
        """Gets the aggregation_type of this UpdateFeatureDto.  # noqa: E501


        :return: The aggregation_type of this UpdateFeatureDto.  # noqa: E501
        :rtype: str
        """
        return self._aggregation_type

    @aggregation_type.setter
    def aggregation_type(self, aggregation_type):
        """Sets the aggregation_type of this UpdateFeatureDto.


        :param aggregation_type: The aggregation_type of this UpdateFeatureDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["avg", "sum"]  # noqa: E501
        if aggregation_type not in allowed_values:
            raise ValueError(
                "Invalid value for `aggregation_type` ({0}), must be one of {1}"  # noqa: E501
                .format(aggregation_type, allowed_values)
            )

        self._aggregation_type = aggregation_type

    @property
    def is_filter(self):
        """Gets the is_filter of this UpdateFeatureDto.  # noqa: E501


        :return: The is_filter of this UpdateFeatureDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_filter

    @is_filter.setter
    def is_filter(self, is_filter):
        """Sets the is_filter of this UpdateFeatureDto.


        :param is_filter: The is_filter of this UpdateFeatureDto.  # noqa: E501
        :type: bool
        """

        self._is_filter = is_filter

    @property
    def is_trainable(self):
        """Gets the is_trainable of this UpdateFeatureDto.  # noqa: E501


        :return: The is_trainable of this UpdateFeatureDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_trainable

    @is_trainable.setter
    def is_trainable(self, is_trainable):
        """Sets the is_trainable of this UpdateFeatureDto.


        :param is_trainable: The is_trainable of this UpdateFeatureDto.  # noqa: E501
        :type: bool
        """

        self._is_trainable = is_trainable

    @property
    def is_explainable(self):
        """Gets the is_explainable of this UpdateFeatureDto.  # noqa: E501


        :return: The is_explainable of this UpdateFeatureDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_explainable

    @is_explainable.setter
    def is_explainable(self, is_explainable):
        """Sets the is_explainable of this UpdateFeatureDto.


        :param is_explainable: The is_explainable of this UpdateFeatureDto.  # noqa: E501
        :type: bool
        """

        self._is_explainable = is_explainable

    @property
    def is_categorical(self):
        """Gets the is_categorical of this UpdateFeatureDto.  # noqa: E501


        :return: The is_categorical of this UpdateFeatureDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_categorical

    @is_categorical.setter
    def is_categorical(self, is_categorical):
        """Sets the is_categorical of this UpdateFeatureDto.


        :param is_categorical: The is_categorical of this UpdateFeatureDto.  # noqa: E501
        :type: bool
        """

        self._is_categorical = is_categorical

    @property
    def category_values(self):
        """Gets the category_values of this UpdateFeatureDto.  # noqa: E501


        :return: The category_values of this UpdateFeatureDto.  # noqa: E501
        :rtype: object
        """
        return self._category_values

    @category_values.setter
    def category_values(self, category_values):
        """Sets the category_values of this UpdateFeatureDto.


        :param category_values: The category_values of this UpdateFeatureDto.  # noqa: E501
        :type: object
        """

        self._category_values = category_values

    @property
    def type(self):
        """Gets the type of this UpdateFeatureDto.  # noqa: E501


        :return: The type of this UpdateFeatureDto.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this UpdateFeatureDto.


        :param type: The type of this UpdateFeatureDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["string", "numeric"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateFeatureDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateFeatureDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 3.9.0-develop.3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ProjectMember(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'user_id': 'str',
        'role': 'str',
        'is_member_default': 'bool',
        'project_id': 'str',
        'project': 'Project',
        'last_updated_by': 'str',
        'created_by': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'archived_at': 'datetime',
        'version': 'float'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'role': 'role',
        'is_member_default': 'isMemberDefault',
        'project_id': 'projectId',
        'project': 'project',
        'last_updated_by': 'lastUpdatedBy',
        'created_by': 'createdBy',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'archived_at': 'archivedAt',
        'version': 'version'
    }

    def __init__(self, id=None, user_id=None, role=None, is_member_default=None, project_id=None, project=None, last_updated_by=None, created_by=None, created_at=None, updated_at=None, archived_at=None, version=None):  # noqa: E501
        """ProjectMember - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._user_id = None
        self._role = None
        self._is_member_default = None
        self._project_id = None
        self._project = None
        self._last_updated_by = None
        self._created_by = None
        self._created_at = None
        self._updated_at = None
        self._archived_at = None
        self._version = None
        self.discriminator = None
        if id is not None:
            self.id = id
        self.user_id = user_id
        self.role = role
        if is_member_default is not None:
            self.is_member_default = is_member_default
        self.project_id = project_id
        if project is not None:
            self.project = project
        if last_updated_by is not None:
            self.last_updated_by = last_updated_by
        if created_by is not None:
            self.created_by = created_by
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if archived_at is not None:
            self.archived_at = archived_at
        if version is not None:
            self.version = version

    @property
    def id(self):
        """Gets the id of this ProjectMember.  # noqa: E501


        :return: The id of this ProjectMember.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProjectMember.


        :param id: The id of this ProjectMember.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this ProjectMember.  # noqa: E501


        :return: The user_id of this ProjectMember.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ProjectMember.


        :param user_id: The user_id of this ProjectMember.  # noqa: E501
        :type: str
        """
        if user_id is None:
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def role(self):
        """Gets the role of this ProjectMember.  # noqa: E501


        :return: The role of this ProjectMember.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this ProjectMember.


        :param role: The role of this ProjectMember.  # noqa: E501
        :type: str
        """
        if role is None:
            raise ValueError("Invalid value for `role`, must not be `None`")  # noqa: E501

        self._role = role

    @property
    def is_member_default(self):
        """Gets the is_member_default of this ProjectMember.  # noqa: E501


        :return: The is_member_default of this ProjectMember.  # noqa: E501
        :rtype: bool
        """
        return self._is_member_default

    @is_member_default.setter
    def is_member_default(self, is_member_default):
        """Sets the is_member_default of this ProjectMember.


        :param is_member_default: The is_member_default of this ProjectMember.  # noqa: E501
        :type: bool
        """

        self._is_member_default = is_member_default

    @property
    def project_id(self):
        """Gets the project_id of this ProjectMember.  # noqa: E501


        :return: The project_id of this ProjectMember.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this ProjectMember.


        :param project_id: The project_id of this ProjectMember.  # noqa: E501
        :type: str
        """
        if project_id is None:
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    @property
    def project(self):
        """Gets the project of this ProjectMember.  # noqa: E501


        :return: The project of this ProjectMember.  # noqa: E501
        :rtype: Project
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this ProjectMember.


        :param project: The project of this ProjectMember.  # noqa: E501
        :type: Project
        """

        self._project = project

    @property
    def last_updated_by(self):
        """Gets the last_updated_by of this ProjectMember.  # noqa: E501


        :return: The last_updated_by of this ProjectMember.  # noqa: E501
        :rtype: str
        """
        return self._last_updated_by

    @last_updated_by.setter
    def last_updated_by(self, last_updated_by):
        """Sets the last_updated_by of this ProjectMember.


        :param last_updated_by: The last_updated_by of this ProjectMember.  # noqa: E501
        :type: str
        """

        self._last_updated_by = last_updated_by

    @property
    def created_by(self):
        """Gets the created_by of this ProjectMember.  # noqa: E501


        :return: The created_by of this ProjectMember.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ProjectMember.


        :param created_by: The created_by of this ProjectMember.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_at(self):
        """Gets the created_at of this ProjectMember.  # noqa: E501


        :return: The created_at of this ProjectMember.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ProjectMember.


        :param created_at: The created_at of this ProjectMember.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this ProjectMember.  # noqa: E501


        :return: The updated_at of this ProjectMember.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ProjectMember.


        :param updated_at: The updated_at of this ProjectMember.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def archived_at(self):
        """Gets the archived_at of this ProjectMember.  # noqa: E501


        :return: The archived_at of this ProjectMember.  # noqa: E501
        :rtype: datetime
        """
        return self._archived_at

    @archived_at.setter
    def archived_at(self, archived_at):
        """Sets the archived_at of this ProjectMember.


        :param archived_at: The archived_at of this ProjectMember.  # noqa: E501
        :type: datetime
        """

        self._archived_at = archived_at

    @property
    def version(self):
        """Gets the version of this ProjectMember.  # noqa: E501


        :return: The version of this ProjectMember.  # noqa: E501
        :rtype: float
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ProjectMember.


        :param version: The version of this ProjectMember.  # noqa: E501
        :type: float
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectMember, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectMember):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
